<?php

defined('ABSPATH') || exit;

use Stoni_Theme_Helper as Stoni;

/**
 * Stoni Dynamic Styles
 *
 *
 * @author WebGeniusLab <webgeniuslab@gmail.com>
 * @since 1.0.0
 * @version 1.1.7
 */
class Stoni_dynamic_styles
{
    public $settings;

    protected static $instance;

    private $template_directory_uri;
    private $theme_slug;
    private $use_minified;
    private $enqueued_stylesheets = [];

    /** @version 1.0.19 */
    public function register_script()
    {
        $this->template_directory_uri = get_template_directory_uri();
        $this->use_minified = Stoni::get_option('use_minified') ? '.min' : '';

        add_action('wp_enqueue_scripts', [$this, 'styles_registration']);
        add_action('wp_enqueue_scripts', [$this, 'scripts_registration']);

        add_action('admin_enqueue_scripts', [$this, 'admin_css_reg']);
        add_action('admin_enqueue_scripts', [$this, 'admin_js_reg']);

        add_action('wp_enqueue_scripts', [$this, 'get_elementor_css_cache_footer'] );
    }

    /**
     * @since 1.0.0
     * @version 1.1.7
     */
    public function styles_registration()
    {
        $this->theme_slug = $this->get_theme_slug();

        wp_enqueue_style('stoni-theme-info', get_bloginfo('stylesheet_url'));

        $this->enqueue_additional_styles();
        $this->enqueue_style('main', '/css/');
        $this->enqueue_pluggable_styles();
        $this->enqueue_style('responsive', '/css/', $this->enqueued_stylesheets);

        if (is_rtl()) {
            $this->enqueue_style('rtl', '/css/');
        }
    }

    /**
     * Enqueue theme stylesheets
     *
     *
     * @since 1.0.19
     *
     * @param string   $tag      Unprefixed handle to pass into native `wp_enqueue_style` function.
     * @param string   $file_dir Path to stylesheet folder, relative to root folder.
     * @param string[] $deps     Optional. An array of registered stylesheet handles this stylesheet depends on. Default empty array.
     */
    public function enqueue_style($tag, $file_dir, $deps = [])
    {
        $prefixed_tag = $this->theme_slug . '-' . $tag;
        $this->enqueued_stylesheets[] = $prefixed_tag;

        wp_enqueue_style(
            $prefixed_tag,
            $this->template_directory_uri . $file_dir . $tag . $this->use_minified . '.css',
            $deps
        );
    }

    /**
     * @since 1.0.19
     * @version 1.1.2
     */
    public function get_theme_slug()
    {
        return str_replace('-child', '', wp_get_theme()->get('TextDomain'));
    }

    /** @since 1.0.19 */
    public function enqueue_pluggable_styles()
    {
        //* Preloader
        if (Stoni::get_option('preloader')) {
            $this->enqueue_style('preloader', '/css/pluggable/');
        }

        //* Page 404|Search
        if (is_404() || is_search()) {
            $this->enqueue_style('page-404', '/css/pluggable/');
        }

        //* WooCommerce Plugin
        if (class_exists('WooCommerce')) {
            $this->enqueue_style('woocommerce', '/css/pluggable/');
        }

        //* Side Panel
        if (Stoni::get_option('side_panel_enable')) {
            $this->enqueue_style('side-panel', '/css/pluggable/');
        }

        //* WPML plugin
        if (class_exists('SitePress')) {
            $this->enqueue_style('wpml', '/css/pluggable/');
        }
    }

    /** @since 1.0.19 */
    public function enqueue_additional_styles()
    {
        wp_enqueue_style('font-awesome', $this->template_directory_uri . '/css/font-awesome.min.css');
        wp_enqueue_style('stoni-flaticon', $this->template_directory_uri . '/fonts/flaticon/flaticon.css');
    }

    /**
     * @since 1.0.0
     * @version 1.0.19
     */
    public function scripts_registration()
    {
        wp_enqueue_script('stoni-theme-addons', $this->template_directory_uri . '/js/theme-addons' . $this->use_minified . '.js', ['jquery'], false, true);
        wp_enqueue_script('stoni-theme', $this->template_directory_uri . '/js/theme.js', ['jquery'], false, true);

        wp_localize_script('stoni-theme', 'wgl_core', [
            'ajaxurl' => admin_url('admin-ajax.php'),
            'slickSlider' => esc_url($this->template_directory_uri . '/js/slick.min.js'),
            'JarallaxPlugin' => esc_url($this->template_directory_uri . '/js/jarallax-video.min.js'),
            'JarallaxPluginVideo' => esc_url($this->template_directory_uri . '/js/jarallax.min.js'),
            'like' => esc_html__('Like', 'stoni'),
            'unlike' => esc_html__('Unlike', 'stoni')
        ]);

        if (is_singular() && comments_open() && get_option('thread_comments')) {
            wp_enqueue_script('comment-reply');
        }

        wp_enqueue_script('perfect-scrollbar', $this->template_directory_uri . '/js/perfect-scrollbar.min.js');
    }

    /** Register css for admin panel */
    public function admin_css_reg()
    {
        wp_enqueue_style('stoni-admin', $this->template_directory_uri . '/core/admin/css/admin.css');
        wp_enqueue_style('font-awesome', $this->template_directory_uri . '/css/font-awesome.min.css');
        wp_enqueue_style('wp-color-picker');
    }

    /** Register css and js for admin panel */
    public function admin_js_reg()
    {
        wp_enqueue_media();
        wp_enqueue_script('wp-color-picker');
        wp_localize_script('wp-color-picker', 'wpColorPickerL10n', array(
			'clear'            => esc_html__('Clear', 'stoni'),
			'clearAriaLabel'   => esc_html__('Clear color', 'stoni'),
			'defaultString'    => esc_html__('Default', 'stoni'),
			'defaultAriaLabel' => esc_html__('Select default color', 'stoni'),
			'pick'             => esc_html__('Select', 'stoni'),
			'defaultLabel'     => esc_html__('Color value', 'stoni'),
		));
        wp_enqueue_script('stoni-admin', $this->template_directory_uri . '/core/admin/js/admin.js');
        if (class_exists('RWMB_Loader')) {
            wp_enqueue_script('stoni-metaboxes', $this->template_directory_uri . '/core/admin/js/metaboxes.js');
        }

        $currentTheme = wp_get_theme();
        $theme_name = $currentTheme->parent() == false ? wp_get_theme()->get('Name') : wp_get_theme()->parent()->get('Name');
        $theme_name = trim($theme_name);

        $purchase_code = $email = '';
        if (Stoni::wgl_theme_activated()) {
            $theme_details = get_option('wgl_licence_validated');
            $purchase_code = $theme_details['purchase'] ?? '';
            $email = $theme_details['email'] ?? '';
        }

        wp_localize_script('stoni-admin', 'wgl_verify', [
            'ajaxurl' => esc_js(admin_url('admin-ajax.php')),
            'wglUrlActivate' => esc_js(Wgl_Theme_Verify::get_instance()->api . 'verification'),
            'wglUrlDeactivate' => esc_js(Wgl_Theme_Verify::get_instance()->api . 'deactivate'),
            'domainUrl' => esc_js(site_url('/')),
            'themeName' => esc_js($theme_name),
            'purchaseCode' => esc_js($purchase_code),
            'email' => esc_js($email),
            'message' => esc_js(esc_html__('Thank you, your license has been validated', 'stoni')),
            'ajax_nonce' => esc_js(wp_create_nonce('_notice_nonce'))
        ]);
    }

    public function get_elementor_css_cache_footer()
    {

        // footer option
        $footer_switch = Stoni_Theme_Helper::get_option('footer_switch');

        if (class_exists('RWMB_Loader') && get_queried_object_id() !== 0) {
            if (rwmb_meta('mb_footer_switch') == 'on') {
                $footer_switch = true;
            } elseif (rwmb_meta('mb_footer_switch') == 'off') {
                $footer_switch = false;
            }
        }

        //hide if 404 page
        $page_not_found = Stoni_Theme_Helper::get_option('404_show_footer');
        if (is_404() && !(bool) $page_not_found) $footer_switch = $copyright_switch = false;

        if ($footer_switch) {
            $footer_content_type = Stoni_Theme_Helper::options_compare('footer_content_type','mb_footer_switch','on');
            if (
                $footer_content_type == 'pages'
                && class_exists('\Elementor\Core\Files\CSS\Post')
            ) {

                $footer_page_select = Stoni_Theme_Helper::options_compare('footer_page_select', 'mb_footer_switch', 'on');

                if ($footer_page_select) {
                    $footer_page_select_id = intval($footer_page_select);

                    if (class_exists('Polylang') && function_exists('pll_current_language')) {
                        $currentLanguage = pll_current_language();
                        $translations = PLL()->model->post->get_translations($footer_page_select_id);

                        $polylang_footer_id = $translations[$currentLanguage] ?? '';
                        $footer_page_select_id = !empty($polylang_footer_id) ? $polylang_footer_id : $footer_page_select_id;
                    }

                    if (class_exists('SitePress')) {
                        $footer_page_select_id = wpml_object_id_filter($footer_page_select_id, 'footer', false, ICL_LANGUAGE_CODE);
                    }

                    $css_file = new \Elementor\Core\Files\CSS\Post($footer_page_select_id);
                    \Elementor\Plugin::$instance->frontend->enqueue_styles();
                    $css_file->enqueue();
                }
            }
        }
    }

    public function init_style()
    {
        add_action('wp_enqueue_scripts', [$this, 'add_style']);
        add_action('wp_enqueue_scripts', [$this, 'elementor_column_fix'] );
    }

    public function minify_css($css = null)
    {
        if (!$css) { return; }
        $css = str_replace( ',{', '{', $css );
        $css = str_replace( ', ', ',', $css );
        $css = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $css );
        $css = str_replace( array("\r\n", "\r", "\n", "\t", '  ', '    ', '    '), '', $css );
        $css = trim( $css );

        return $css;
    }

    public function add_style()
    {
        $css = '';

        /*-----------------------------------------------------------------------------------*/
        /* Body Style
        /*-----------------------------------------------------------------------------------*/
        $page_colors_switch = Stoni::options_compare('page_colors_switch', 'mb_page_colors_switch', 'custom');
        $use_gradient_switch = Stoni::options_compare('use-gradient', 'mb_page_colors_switch', 'custom');
        if ($page_colors_switch == 'custom') {
            $theme_color = Stoni::options_compare('page_theme_color', 'mb_page_colors_switch', 'custom');
            $theme_secondary_color = Stoni::options_compare('page_theme_secondary_color', 'mb_page_colors_switch', 'custom');

            $bg_body = Stoni::options_compare('body_background_color', 'mb_page_colors_switch', 'custom');
            //* Go top color
            $scroll_up_bg_color = Stoni::options_compare('scroll_up_bg_color', 'mb_page_colors_switch', 'custom');
            $scroll_up_arrow_color = Stoni::options_compare('scroll_up_arrow_color', 'mb_page_colors_switch', 'custom');
            //* Gradient colors
            $theme_gradient_from = Stoni::options_compare('theme-gradient-from', 'mb_page_colors_switch', 'custom');
            $theme_gradient_to = Stoni::options_compare('theme-gradient-to', 'mb_page_colors_switch', 'custom');
        } else {
            $theme_color = esc_attr(Stoni::get_option('theme-custom-color'));
            $theme_secondary_color = esc_attr(Stoni::get_option('theme-secondary-color'));

            $bg_body = esc_attr(Stoni::get_option('body-background-color'));
            //* Go top color
            $scroll_up_bg_color = Stoni::get_option('scroll_up_bg_color');
            $scroll_up_arrow_color = Stoni::get_option('scroll_up_arrow_color');
            //* Gradient colors
            $theme_gradient = Stoni::get_option('theme-gradient');
            $second_gradient = Stoni::get_option('second-gradient');
            $theme_gradient_from = $theme_gradient['from'];
            $theme_gradient_to = $theme_gradient['to'];
        }
        /*-----------------------------------------------------------------------------------*/
        /* \End Body style
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /* Body Add Class
        /*-----------------------------------------------------------------------------------*/
        if ($use_gradient_switch) {
            add_filter('body_class', function ($classes) {
                return array_merge($classes, ['theme-gradient']);
            });
            $gradient_class = '.theme-gradient';
        } else {
            $gradient_class = '';
        }

        if (
            defined('ELEMENTOR_VERSION')
            && version_compare(ELEMENTOR_VERSION, '3.0', '>=')
            && (empty(get_option('elementor_element_wrappers_legacy_mode')) 
            || \Elementor\Plugin::$instance->experiments->is_feature_active( 'e_dom_optimization' ))
        ) {
            add_filter('body_class', function ($classes) {
                $classes[] = 'new-elementor';
                return $classes;
            } );
        }
        /*-----------------------------------------------------------------------------------*/
        /* End Body Add Class
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /* Header Typography
        /*-----------------------------------------------------------------------------------*/
        $header_font = Stoni::get_option('header-font');
        $bg_font = Stoni::get_option('background-font');

        $bg_font_family = $bg_font_weight = '';
        if (!empty($bg_font)) {
            $bg_font_family = esc_attr($bg_font['font-family']);
            $bg_font_weight = esc_attr($bg_font['font-weight']);
        }

        $header_font_family = $header_font_weight = $header_font_color = '';
        if (!empty($header_font)) {
            $header_font_family = esc_attr($header_font['font-family']);
            $header_font_weight = esc_attr($header_font['font-weight']);
            $header_font_color = esc_attr($header_font['color']);
        }

        //* Add headings variables
        for ($i = 1; $i <= 6; $i++) {
            ${'header-h' . $i} = Stoni::get_option('header-h' . $i);
            ${'header-h' . $i . '_family'} = ${'header-h' . $i . '_weight'} = ${'header-h' . $i . '_line_height'} = ${'header-h' . $i . '_size'} = ${'header-h' . $i . '_text_transform'} = '';

            if (!empty(${'header-h' . $i})) {
                ${'header-h' . $i . '_family'} = !empty(${'header-h' . $i}["font-family"]) ? esc_attr(${'header-h' . $i}["font-family"]) : '';
                ${'header-h' . $i . '_weight'} = !empty(${'header-h' . $i}["font-weight"]) ? esc_attr(${'header-h' . $i}["font-weight"]) : '';
                ${'header-h' . $i . '_line_height'} = !empty(${'header-h' . $i}["line-height"]) ? esc_attr(${'header-h' . $i}["line-height"]) : '';
                ${'header-h' . $i . '_size'} = !empty(${'header-h' . $i}["font-size"]) ? esc_attr(${'header-h' . $i}["font-size"]) : '';
                ${'header-h' . $i . '_text_transform'} = !empty(${'header-h' . $i}["text-transform"]) ? esc_attr(${'header-h' . $i}["text-transform"]) : '';
            }
        }
        /*-----------------------------------------------------------------------------------*/
        /* \End Header Typography
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /* Body Typography
        /*-----------------------------------------------------------------------------------*/
        $main_font = Stoni::get_option('main-font');
        $content_font_family = $content_line_height = $content_font_size = $content_font_weight = $content_color = '';
        if (!empty($main_font)) {
            $content_font_family = esc_attr($main_font['font-family']);
            $content_font_size = esc_attr($main_font['font-size']);
            $content_font_weight = esc_attr($main_font['font-weight']);
            $content_color = esc_attr($main_font['color']);
            $content_line_height = esc_attr($main_font['line-height']);
            $content_line_height = !empty($content_line_height) ? round(((int)$content_line_height / (int)$content_font_size), 3) : '';
        }
        /*-----------------------------------------------------------------------------------*/
        /* \End Body Typography
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /* Menu, Sub-menu Typography
        /*-----------------------------------------------------------------------------------*/
        $menu_font = Stoni::get_option('menu-font');
        $menu_font_family = $menu_font_weight = $menu_font_line_height = $menu_font_size = '';
        if (!empty($menu_font)) {
            $menu_font_family = !empty($menu_font['font-family']) ? esc_attr($menu_font['font-family']) : '';
            $menu_font_weight = !empty($menu_font['font-weight']) ? esc_attr($menu_font['font-weight']) : '';
            $menu_font_line_height = !empty($menu_font['line-height']) ? esc_attr($menu_font['line-height']) : '';
            $menu_font_size = !empty($menu_font['font-size']) ? esc_attr($menu_font['font-size']) : '';
        }

        $sub_menu_font = Stoni::get_option('sub-menu-font');
        $sub_menu_font_family = $sub_menu_font_weight = $sub_menu_font_line_height = $sub_menu_font_size = '';
        if (!empty($sub_menu_font)) {
            $sub_menu_font_family = !empty($sub_menu_font['font-family']) ? esc_attr($sub_menu_font['font-family']) : '';
            $sub_menu_font_weight = !empty($sub_menu_font['font-weight']) ? esc_attr($sub_menu_font['font-weight']) : '';
            $sub_menu_font_line_height = !empty($sub_menu_font['line-height']) ? esc_attr($sub_menu_font['line-height']) : '';
            $sub_menu_font_size = !empty($sub_menu_font['font-size']) ? esc_attr($sub_menu_font['font-size']) : '';
        }
        /*-----------------------------------------------------------------------------------*/
        /* \End Menu, Sub-menu Typography
        /*-----------------------------------------------------------------------------------*/

        $name_preset = Stoni::header_preset_name();
        $get_def_name = get_option('stoni_set_preset');
        $def_preset = false;
        if (isset($get_def_name['default']) && $name_preset) {
            if (array_key_exists($name_preset, $get_def_name['default']) && !array_key_exists($name_preset, $get_def_name)) {
                $def_preset = true;
            }
        }

        $menu_color_top = Stoni::get_option('header_top_color', $name_preset, $def_preset)['rgba'] ?? '';
        $menu_color_middle = Stoni::get_option('header_middle_color', $name_preset, $def_preset)['rgba'] ?? '';
        $menu_color_bottom = Stoni::get_option('header_bottom_color', $name_preset, $def_preset)['rgba'] ?? '';

        //* Set Queries width to apply mobile style
        $sub_menu_color = Stoni::get_option('sub_menu_color', $name_preset, $def_preset);
        $sub_menu_bg = Stoni::get_option('sub_menu_background', $name_preset, $def_preset);
        $sub_menu_bg = $sub_menu_bg['rgba'];

        $mobile_sub_menu_bg = Stoni::get_option('mobile_sub_menu_background')['rgba'];
        $mobile_sub_menu_overlay = Stoni::get_option('mobile_sub_menu_overlay')['rgba'];
        $mobile_sub_menu_color = Stoni::get_option('mobile_sub_menu_color');

        $hex_header_font_color = Stoni::HexToRGB($header_font_color);
        $hex_theme_color = Stoni::HexToRGB($theme_color);

        $hex_theme_content =  Stoni::HexToRGB($content_color);

        // sticky header logo
        $header_sticky_height = Stoni::get_option('header_sticky_height');
        $header_sticky_height = (int) $header_sticky_height['height'] . 'px';
        // sticky header color
        $header_sticky_color = Stoni::get_option('header_sticky_color');

        $footer_text_color = Stoni::get_option('footer_text_color');
        $footer_heading_color = Stoni::get_option('footer_heading_color');

        $copyright_text_color = Stoni::options_compare('copyright_text_color', 'mb_copyright_switch', 'on');

        //* Page Title Background Color
        $page_title_bg_color = Stoni::get_option('page_title_bg_color');
        $hex_page_title_bg_color = Stoni::HexToRGB($page_title_bg_color);

        /*-----------------------------------------------------------------------------------*/
        /* Shop Dynamic Css
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /* Side Panel CSS
        /*-----------------------------------------------------------------------------------*/
        $side_panel_title = Stoni::get_option('side_panel_title_color')['rgba'] ?? '';

        if (
            class_exists('RWMB_Loader')
            && get_queried_object_id() !== 0
            && rwmb_meta('mb_customize_side_panel') === 'custom'
        ) {
            $side_panel_title = rwmb_meta('mb_side_panel_title_color');
        }
        /*-----------------------------------------------------------------------------------*/
        /* \End Side Panel CSS
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /* Parse CSS
        /*-----------------------------------------------------------------------------------*/
        global $wp_filesystem;
        if (empty($wp_filesystem)) {
            require_once ABSPATH . '/wp-admin/includes/file.php';
            WP_Filesystem();
        }

        $files = ['theme_content', 'theme_color', 'footer'];
        if (class_exists('WooCommerce')) {
            array_push($files, 'shop');
        }
        foreach ($files as $file) {
            $file = get_theme_file_path('/core/admin/css/dynamic/' . $file . '.css');
            if ($wp_filesystem->exists($file)) {
                $file = $wp_filesystem->get_contents($file);
                preg_match_all('/\s*\\$([A-Za-z1-9_\-]+)(\s*:\s*(.*?);)?\s*/', $file, $vars);

                $found = $vars[0];
                $varNames = $vars[1];
                $count = count($found);

                for ($i = 0; $i < $count; $i++) {
                    $varName = trim($varNames[$i]);
                    $file = preg_replace('/\\$' . $varName . '(\W|\z)/', (isset(${$varName}) ? ${$varName} : '') . '\\1', $file);
                }

                $line = str_replace($found, '', $file);

                $css .= $line;
            }
        }
        /*-----------------------------------------------------------------------------------*/
        /* \End Parse css
        /*-----------------------------------------------------------------------------------*/
        $css .= 'body {'
            . (!empty($bg_body) ? 'background: ' . $bg_body . ';' : '') . '
        }
        ol.commentlist:after {
            ' . (!empty($bg_body) ? 'background: ' . $bg_body . ';' : '') . '
        }';
        /*-----------------------------------------------------------------------------------*/
        /* Typography render
        /*-----------------------------------------------------------------------------------*/
        for ($i = 1; $i <= 6; $i++) {
            $css .= 'h' . $i . ',h' . $i . ' a, h' . $i . ' span,
            .elementor-widget-heading h' . $i . '.elementor-heading-title,
            .elementor-widget-heading h' . $i . '.elementor-heading-title a,
            .elementor-widget-heading h' . $i . '.elementor-heading-title span {
                ' . (!empty(${'header-h' . $i . '_family'}) ? 'font-family:' . ${'header-h' . $i . '_family'} . ';' : '') . '
                ' . (!empty(${'header-h' . $i . '_weight'}) ? 'font-weight:' . ${'header-h' . $i . '_weight'} . ';' : '') . '
                ' . (!empty(${'header-h' . $i . '_size'}) ? 'font-size:' . ${'header-h' . $i . '_size'} . ';' : '') . '
                ' . (!empty(${'header-h' . $i . '_line_height'}) ? 'line-height:' . ${'header-h' . $i . '_line_height'} . ';' : '') . '
                ' . (!empty(${'header-h' . $i . '_text_transform'}) ? 'text-transform:' . ${'header-h' . $i . '_text_transform'} . ';' : '') . '
            }';
        }
        /*-----------------------------------------------------------------------------------*/
        /* \End Typography render
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /* Mobile Header render
        /*-----------------------------------------------------------------------------------*/
        //* Fetch mobile header height to apply it for mobile styles
        $header_mobile_height = Stoni::get_option('header_mobile_height');
        $header_mobile_height = !empty($header_mobile_height['height']) ? 'calc(100vh - ' . esc_attr((int) $header_mobile_height['height']) . 'px)' : '';

        //* Set Queries width to apply mobile style
        $header_queries = Stoni::get_option('header_mobile_queris', $name_preset, $def_preset);
        $mobile_sticky = Stoni::get_option('mobile_sticky');

        if (Stoni::get_option('mobile_header')) {
            $mobile_background = Stoni::get_option('mobile_background')['rgba'] ?? '';
            $mobile_color = Stoni::get_option('mobile_color');

            $css .= '@media only screen and (max-width: ' . (int) $header_queries . 'px) {
                .wgl-theme-header {
                    background-color: ' . esc_attr($mobile_background) . ' !important;
                    color: ' . esc_attr($mobile_color) . ' !important;
                }
                .hamburger-inner, .hamburger-inner:before, .hamburger-inner:after {
                    background-color: ' . esc_attr($mobile_color) . ';
                }
            }';
        }

        $css .= '@media only screen and (max-width: ' . (int) $header_queries . 'px) {
            .wgl-theme-header .wgl-mobile-header {
                display: block;
            }
            .wgl-site-header {
                display: none;
            }
            .wgl-theme-header .mobile-hamburger-toggle {
                display: inline-block;
            }
            .wgl-theme-header .primary-nav {
                display: none;
            }
            header.wgl-theme-header .mobile_nav_wrapper .primary-nav {
                display: block;
            }
            .wgl-theme-header .wgl-sticky-header {
                display: none;
            }
            .wgl-social-share_pages {
                display: none;
            }
        }';

        if (Stoni::get_option('mobile_over_content')) {
            $css .= '@media only screen and (max-width: ' . (int) $header_queries . 'px) {
                .wgl-theme-header {
                    position: absolute;
                    z-index: 99;
                    width: 100%;
                    left: 0;
                    top: 0;
                }
            }';
            if ($mobile_sticky) {
                $css .= '@media only screen and (max-width: ' . (int) $header_queries . 'px) {
                    body .wgl-theme-header .wgl-mobile-header {
                        position: absolute;
                        left: 0;
                        width: 100%;
                    }
                }';
            }
        } else {
            $css .= '@media only screen and (max-width: ' . (int) $header_queries . 'px) {
                body .wgl-theme-header.header_overlap {
                    position: relative;
                    z-index: 2;
                }
            }';
        }

        if ($mobile_sticky) {
            $css .= '@media only screen and (max-width: ' . (int) $header_queries . 'px) {
                body .wgl-theme-header,
                body .wgl-theme-header.header_overlap {
                    position: sticky;
                    top: 0;
                }
                .admin-bar .wgl-theme-header {
                    top: 32px;
                }
                body.mobile_switch_on {
                    position: static;
                }
                body.admin-bar .sticky_mobile .wgl-menu_outer{
                    top: 0px;
                    height: 100vh;
                }
            }';
        }
        /*-----------------------------------------------------------------------------------*/
        /* \End Mobile Header render
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /* Page Title Responsive
        /*-----------------------------------------------------------------------------------*/
        $page_title_resp = Stoni::get_option('page_title_resp_switch');
        $mb_cond_logic = false;

        $id = !is_archive() ? get_queried_object_id() : 0;
        if (
            class_exists('RWMB_Loader')
            && $id !== 0
        ) {
            $mb_cond_logic = rwmb_meta('mb_page_title_switch') == 'on' && rwmb_meta('mb_page_title_resp_switch') == '1' ? '1' : '';

            if (
                rwmb_meta('mb_page_title_switch') == 'on'
                && rwmb_meta('mb_page_title_resp_switch') == '1'
            ) {
                $page_title_resp = '1';
            }
        }

        if ($page_title_resp) {
            $pt_breakpoint = (int) Stoni::options_compare('page_title_resp_resolution', 'mb_page_title_resp_switch', $mb_cond_logic);
            $pt_padding = Stoni::options_compare('page_title_resp_padding', 'mb_page_title_resp_switch', $mb_cond_logic);

            $pt_height = Stoni::get_option('page_title_resp_height')['height'] ?? '';
            if ($mb_cond_logic) {
                $pt_height = rwmb_meta('mb_page_title_resp_height');
            }

            $pt_font = Stoni::options_compare('page_title_resp_font', 'mb_page_title_resp_switch', $mb_cond_logic);
            $breadcrumbs_font = Stoni::options_compare('page_title_resp_breadcrumbs_font', 'mb_page_title_resp_switch', $mb_cond_logic);
            $breadcrumbs_switch = Stoni::options_compare('page_title_resp_breadcrumbs_switch', 'mb_page_title_resp_switch', $mb_cond_logic);

            //* Title styles
            $pt_color = !empty($pt_font['color']) ? 'color: ' . esc_attr($pt_font['color']) . ' !important;' : '';
            $pt_f_size = !empty($pt_font['font-size']) ? ' font-size: ' . esc_attr((int) $pt_font['font-size']) . 'px !important;' : '';
            $pt_line_height = !empty($pt_font['line-height']) ? ' line-height: ' . esc_attr((int) $pt_font['line-height']) . 'px !important;' : '';
            $pt_additional_style = !(bool) $breadcrumbs_switch ? ' margin-bottom: 0 !important;' : '';
            $title_style = $pt_color . $pt_f_size . $pt_line_height . $pt_additional_style;

            //* Breadcrumbs Styles
            $breadcrumbs_color = !empty($breadcrumbs_font['color']) ? 'color: ' . esc_attr($breadcrumbs_font['color']) . ' !important;' : '';
            $breadcrumbs_f_size = !empty($breadcrumbs_font['font-size']) ? 'font-size: ' . esc_attr((int) $breadcrumbs_font['font-size']) . 'px !important;' : '';
            $breadcrumbs_line_height = !empty($breadcrumbs_font['line-height']) ? 'line-height: ' . esc_attr((int) $breadcrumbs_font['line-height']) . 'px !important;' : '';
            $breadcrumbs_display = !(bool) $breadcrumbs_switch ? 'display: none !important;' : '';
            $breadcrumbs_style = $breadcrumbs_color . $breadcrumbs_f_size . $breadcrumbs_line_height . $breadcrumbs_display;

            $css .= '@media only screen and (max-width: ' . $pt_breakpoint . 'px) {
                .page-header {
                    ' . (!empty($pt_padding['padding-top']) ? 'padding-top: ' . esc_attr((int) $pt_padding['padding-top']) . 'px !important;' : '') . '
                    ' . (!empty($pt_padding['padding-bottom']) ? 'padding-bottom: ' . esc_attr((int) $pt_padding['padding-bottom']) . 'px  !important;' : '') . '
                    ' . (!empty($pt_height) ? 'height: ' . (int) $pt_height . 'px !important;' : '') . '
                }
                .page-header_content .page-header_title {
                    ' . $title_style . '
                }
                .page-header_content .page-header_breadcrumbs {
                    ' . $breadcrumbs_style . '
                }
            }';
        }
        /*-----------------------------------------------------------------------------------*/
        /* \End Page Title Responsive
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /* Footer page CSS
        /*-----------------------------------------------------------------------------------*/
        if (Stoni::get_option('footer_switch')) {
            $footer_content_type = Stoni::get_option('footer_content_type');
            if (
                class_exists('RWMB_Loader')
                && get_queried_object_id() !== 0
                && rwmb_meta('mb_footer_switch') == 'on'
            ) {
                $footer_content_type = rwmb_meta('mb_footer_content_type');
            }

            if (
                $footer_content_type == 'pages'
                && $footer_page_id = Stoni::options_compare('footer_page_select')
            ) {
                $footer_page_id = intval($footer_page_id);
                $shortcodes_css = get_post_meta($footer_page_id, '_wpb_shortcodes_custom_css', true);
                if (!empty($shortcodes_css)) {
                    $shortcodes_css = strip_tags($shortcodes_css);
                    $css .= $shortcodes_css;
                }
            }
        }
        /*-----------------------------------------------------------------------------------*/
        /* \End Footer page CSS
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /* Gradient CSS
        /*-----------------------------------------------------------------------------------*/
        require_once get_template_directory() . '/core/admin/css/dynamic/gradient.php';
        /*-----------------------------------------------------------------------------------*/
        /* \End Gradient CSS
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /* Elementor Theme CSS
        /*-----------------------------------------------------------------------------------*/
        if (did_action('elementor/loaded')) {

            if (defined('ELEMENTOR_VERSION')) {
                if (version_compare(ELEMENTOR_VERSION, '3.0', '<')) {
                    $container_width = get_option('elementor_container_width');
                    $container_width = !empty($container_width) ? $container_width : 1140;
                } else {
                    //* Page settings manager
                    $page_settings_manager = \Elementor\Core\Settings\Manager::get_settings_managers('page');
                    $kit_id = (new \Elementor\Core\Kits\Manager())->get_active_id();

                    $meta_key = \Elementor\Core\Settings\Page\Manager::META_KEY;
                    $kit_settings = get_post_meta($kit_id, $meta_key, true);

                    if (!$kit_settings) {
                        $container_width = 1140;
                     } else {
                        $container_width = $kit_settings['container_width']['size'] ?? 1140;
                    }
                }
            }

            $css .= 'body.elementor-page main .wgl-container.wgl-content-sidebar,
            body.elementor-editor-active main .wgl-container.wgl-content-sidebar,
            body.elementor-editor-preview main .wgl-container.wgl-content-sidebar {
                max-width: ' . intval($container_width) . 'px;
                margin-left: auto;
                margin-right: auto;
            }';

            $css .= 'body.single main .wgl-container {
                max-width: ' . intval($container_width) . 'px;
                margin-left: auto;
                margin-right: auto;
            }';
        }
        /*-----------------------------------------------------------------------------------*/
        /* \End Elementor Theme css
        /*-----------------------------------------------------------------------------------*/

        /**
         * Dynamic CSS
         */

        $css = $this->minify_css($css);

        wp_add_inline_style($this->theme_slug . '-' . 'responsive', $css);

        /** ↑ dynamic css */
    }

    public function elementor_column_fix()
    {
        $css = '.elementor-column-gap-default > .elementor-column > .elementor-element-populated {
            padding-left: 15px;
            padding-right: 15px;
        }';

        wp_add_inline_style('elementor-frontend', $css);
    }

    public static function instance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }
}

if (!function_exists('stoni_dynamic_styles')) {
    function stoni_dynamic_styles()
    {
        return Stoni_dynamic_styles::instance();
    }
}

stoni_dynamic_styles()->register_script();
stoni_dynamic_styles()->init_style();
